summaryrefslogtreecommitdiffstats
path: root/juk/playlistexporter.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/playlistexporter.h')
-rw-r--r--juk/playlistexporter.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/juk/playlistexporter.h b/juk/playlistexporter.h
index 3caae65f..39f13605 100644
--- a/juk/playlistexporter.h
+++ b/juk/playlistexporter.h
@@ -18,8 +18,8 @@
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
/**
* Abstract base class to define an interface for classes that export
@@ -35,13 +35,13 @@ public:
virtual ~PlaylistExporter() { }
/**
* Returns a KAction that can be used to invoke the export.
* Returns 0 if it is not possible.
*
* @return pointer to a KAction that can invoke the export, or 0 on
* failure.
*/
- virtual KAction *action() = 0;
+ virtual TDEAction *action() = 0;
};
#endif /* PLAYLISTEXPORTER_H */
@@ -35,13 +35,13 @@ public:
virtual ~PlaylistExporter() { }
/**
- * Returns a KAction that can be used to invoke the export.
+ * Returns a TDEAction that can be used to invoke the export.
* Returns 0 if it is not possible.
*
@@ -35,13 +35,13 @@ public:
* Returns 0 if it is not possible.
*
- * @return pointer to a KAction that can invoke the export, or 0 on
+ * @return pointer to a TDEAction that can invoke the export, or 0 on
* failure.
*/